==> neuroflex-0.0.3.tar.gz: neuroflex-0.0.3/setup.py <==
from setuptools import setup, find_packages

setup(
    name="neuroflex",
    version="0.0.3",
    author="kasinadhsarma",
    author_email="kasinadhsarma@gmail.com",
    description="An advanced neural network framework with interpretability, generalization, robustness, and fairness features",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/VishwamAI/neuroflex",
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
    python_requires=">=3.8",
    install_requires=[
        "jax>=0.3.0",
        "jaxlib>=0.3.0",
        "ml_dtypes",
        "flax>=0.6.0",
        "optax",
        "tensorflow-cpu",
        "keras",
        "gym",
        "pytest",
        "flake8",
        "numpy",
        "scipy",
        "matplotlib",
        "aif360",
        "packaging",
        "gast",
        "wrapt",
        "pennylane",
        "ibm-watson-machine-learning",
        "scikit-learn",
        "pandas",
        "adversarial-robustness-toolbox",
        "lale",
        "qutip",
        "pyquil",
        "qiskit",
        "biopython",
        "scikit-bio",
        "ete3",
        "xarray",
        "torch",
        # Removed direct GitHub dependency: "alphafold @ git+https://github.com/google-deepmind/alphafold.git"
        # If needed, install alphafold separately or specify a PyPI-compatible version
        "shap",
    ],
    extras_require={
        'dev': [
            'pytest',
            'flake8',
        ],
    },
)

==> neuroflex-0.1.2.tar.gz: neuroflex-0.1.2/setup.py <==
from setuptools import setup, find_packages

setup(
    name="neuroflex",
    version="0.1.2",  # Updated version to match README
    author="kasinadhsarma",
    author_email="kasinadhsarma@gmail.com",
    description="An advanced neural network framework with interpretability, generalization, robustness, and fairness features",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/VishwamAI/neuroflex",
    packages=find_packages(exclude=["tests*"]),  # Updated to find packages in the root directory
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
    ],
    python_requires=">=3.8",
    install_requires=[
        "jax>=0.4.13",
        "jaxlib>=0.4.13",
        "ml_dtypes",
        "flax>=0.6.10",
        "optax",
        "tensorflow-cpu",
        "keras",
        "gym",
        "numpy==1.23.5",
        "scipy==1.9.0",
        "matplotlib",
        "aif360",
        "packaging",
        "gast<=0.4.0,>=0.2.1",
        "wrapt",
        "pennylane==0.30.0",
        "ibm-watson-machine-learning",
        "scikit-learn==1.1.1",
        "pandas",
        "adversarial-robustness-toolbox",
        "lale==0.6.0",
        "qutip",
        "pyquil",
        "qiskit>=1.0.0",
        "biopython==1.79",
        "scikit-bio>=0.5.8,<0.6.0",
        "ete3",
        "xarray",
        "torch==1.13.1",
        "shap",
        "whisper",
        "openmm==8.1.1",  # Updated to match requirements.txt
        "transformers==4.30.2",
        "torchvision==0.14.1",
        "pytorch-lightning==1.9.5",
    ],
    extras_require={
        'dev': [
            'pytest',
            'flake8',
        ],
    },
)
